@@ -1,3 +1,6 @@
+"""Python filesystem abstraction layer.
+"""
+
 __import__('pkg_resources').declare_namespace(__name__)
 
 from ._version import __version__
