@@ -1,5 +1,6 @@
 # coding: utf-8
-"""Defines the TempOpener."""
+"""`TempFS` opener definition.
+"""
 
 from __future__ import absolute_import
 from __future__ import print_function
@@ -8,6 +9,9 @@ from __future__ import unicode_literals
 from .base import Opener
 
 class TempOpener(Opener):
+    """`TempFS` opener.
+    """
+    
     protocols = ['temp']
 
     def open_fs(self, fs_url, parse_result, writeable, create, cwd):
